@@ -7,6 +7,7 @@ import subprocess
 import argparse
 import pprint
 import shutil
+import sysconfig
 from yggdrasil import constants
 LANGUAGES = getattr(constants, 'LANGUAGES', {})
 LANGUAGES_WITH_ALIASES = getattr(constants, 'LANGUAGES_WITH_ALIASES', {})
@@ -176,7 +177,7 @@ class SubCommand(metaclass=SubCommandMeta):
                 cls.add_argument_to_parser(parser, xx)
         elif isinstance(x, (tuple, ArgumentTuple,
                             ConditionalArgumentTuple)):
-            assert(len(x) == 2)
+            assert len(x) == 2
             args, kwargs = x[:]
             try:
                 parser.add_argument(*args, **kwargs)
@@ -341,6 +342,10 @@ class integration_service_manager(SubCommand):
                           'help': ('URL for a directory in a Git repository '
                                    'containing models that should be loaded '
                                    'into the service manager registry.')}),
+                        (('--track-memory', ),
+                         {'action': 'store_true',
+                          'help': ('Track the memory used by the '
+                                   'service manager.')}),
                         (('--log-level', ),
                          {'type': int,
                           'help': ('Level of logging that should be '
@@ -425,7 +430,8 @@ class integration_service_manager(SubCommand):
                         with_coverage=getattr(args, 'with_coverage', False),
                         model_repository=getattr(args, 'model_repository',
                                                  None),
-                        log_level=getattr(args, 'log_level', None))
+                        log_level=getattr(args, 'log_level', None),
+                        track_memory=getattr(args, 'track_memory', False))
             else:
                 x.send_request(integration_name,
                                yamls=integration_yamls,
@@ -624,8 +630,11 @@ class ygginfo(SubCommand):
                                     drv.is_comm_installed()))
                     vardict.append((curr_prefix + "Configured",
                                     drv.is_configured()))
-                    vardict.append((curr_prefix + "Disabled",
-                                    drv.is_disabled()))
+                    if not vardict[-1][1]:
+                        curr_prefix += prefix
+                        for k, v in drv.configuration_steps().items():
+                            vardict.append((curr_prefix + k, v))
+                        curr_prefix = curr_prefix.rsplit(prefix, 1)[0]
                     curr_prefix = curr_prefix.rsplit(prefix, 1)[0]
                 curr_prefix = curr_prefix.rsplit(prefix, 1)[0]
             # Add comm information
@@ -684,7 +693,8 @@ class ygginfo(SubCommand):
                 # Environment variabless
                 env_vars = ['CONDA_PREFIX', 'CONDA', 'SDKROOT', 'CC',
                             'CXX', 'FC', 'GFORTRAN', 'DISPLAY', 'CL',
-                            '_CL_']
+                            '_CL_', 'LD', 'CFLAGS', 'CXXFLAGS',
+                            'LDFLAGS']
                 if platform._is_win:  # pragma: windows
                     env_vars += ['VCPKG_ROOT']
                 vardict.append(('Environment variables:', ''))
@@ -693,6 +703,9 @@ class ygginfo(SubCommand):
                     vardict.append(
                         (curr_prefix + k, os.environ.get(k, None)))
                 curr_prefix = curr_prefix.rsplit(prefix, 1)[0]
+                # Locations of executables
+                for x in ['git', 'mpiexec', 'mpicc']:
+                    vardict.append((f'{x} Location:', shutil.which(x)))
                 # Conda info
                 if os.environ.get('CONDA_PREFIX', ''):
                     if platform._is_win:  # pragma: windows
@@ -824,6 +837,12 @@ class ygginfo(SubCommand):
                              curr_prefix + prefix,
                              ("\n" + curr_prefix + prefix).join(
                                  out.splitlines(False)))))
+                # System config vars
+                vardict.append(('Sysconfig Vars:', ''))
+                curr_prefix += prefix
+                for k, v in sysconfig.get_config_vars().items():
+                    vardict.append((curr_prefix + k, v))
+                curr_prefix = curr_prefix.rsplit(prefix, 1)[0]
         finally:
             # Print things
             max_len = max(len(x[0]) for x in vardict)
@@ -1074,17 +1093,29 @@ class ygginstall(SubCommand):
 
     name = "install"
     help = "Complete yggdrasil installation for one or more languages."
+    arguments = (
+        [(('languages', ),
+          {'nargs': '*',
+           # 'choices': ['all'] + LANGUAGES_WITH_ALIASES.get('all', []),
+           'default': [],
+           'help': 'One or more languages that should be configured.'}),
+         (('--no-import', ),
+          {'action': 'store_true',
+           'help': ('Don\'t import the yggdrasil package in '
+                    'calling the installation script.')}),
+         ]
+    )
 
     @classmethod
-    def get_parser(cls, **kwargs):
+    def add_arguments(cls, parser, **kwargs):
         from yggdrasil.languages import install_languages
-        # TODO: Migrate
-        return install_languages.update_argparser()
+        super(ygginstall, cls).add_arguments(parser, **kwargs)
+        install_languages.update_argparser(parser=parser)
 
     @classmethod
     def func(cls, args):
         from yggdrasil.languages import install_languages
-        languages = args.language
+        languages = args.languages
         if (((isinstance(languages, str) and (languages == 'all'))
              or (isinstance(languages, list) and ('all' in languages)))):
             languages = [x.lower() for x in
@@ -1232,7 +1263,7 @@ class update_config(SubCommand):
             return
         for x_true, x_false in cls.opposite_arguments:
             if getattr(args, x_false, None) is not None:
-                assert(getattr(args, x_true, None) is None)
+                assert getattr(args, x_true, None) is None
                 setattr(args, x_true, not getattr(args, x_false))
             if hasattr(args, x_false):
                 delattr(args, x_false)
@@ -1334,392 +1365,6 @@ class yggdevup(SubCommand):
         ygginfo(args=[])
 
 
-class run_tsts(SubCommand):
-    r"""Run yggdrasil test suite."""
-    # TODO: Move this into a pytest extension?
-
-    name = "test"
-    help = 'Run yggdrasil tests.'
-    arguments = [
-        (('--withcoverage', '--with-coverage'),
-         {'action': 'store_true',
-          'help': 'Record coverage during tests.'}),
-        (('--verbose', '-v'),
-         {'action': 'store_true',
-          'help': 'Increase verbosity of output from the test runner'}),
-        (('--nocapture', '-s'),
-         {'action': 'store_true',
-          'help': 'Don\'t capture output from tests.'}),
-        (('--stop', '-x'),
-         {'action': 'store_true',
-          'help': 'Stop after first test failure.'}),
-        (('--nologcapture', ),
-         {'action': 'store_true',
-          'help': ('Don\'t capture output from log messages '
-                   'generated during tests.')}),
-        (('--noflaky', '--no-flaky'),
-         {'action': 'store_true',
-          'help': 'Don\'t re-run flaky tests.'}),
-        (('--ci', ),
-         {'action': 'store_true',
-          'help': ('Perform addition operations required for '
-                   'testing on continuous integration services.')}),
-        (('--test-suite', '--test-suites'),
-         {'nargs': '+', 'action': 'extend', 'type': str,
-          'choices': ['all', 'top', 'examples', 'examples_part1',
-                      'examples_part2', 'demos', 'types', 'timing',
-                      'connections', 'models', 'mpi'],
-          'help': 'Test suite(s) that should be run.',
-          'dest': 'test_suites'}),
-        (('--pytest-config', '-c'),
-         {'help': ('Pytest configuration file that should be used '
-                   'instead of the defaults.')}),
-        (('--cov-config', ),
-         {'help': 'Config file for coverage. Default: .coveragerc'}),
-        (('--ignore', ),
-         {'action': 'append',
-          'help': 'Ignore path during collection.'}),
-        (('--rootdir', ),
-         {'help': 'Define root directory for tests.'}),
-        (('--count', ),
-         {'type': int, 'default': 1,
-          'help': 'Number of times to repeat a test.'}),
-        (('--additional-info', '-r'),
-         {'type': str, 'default': '',
-          'help': 'Display additional info for test results.'}),
-        (('--with-mpi', '--mpi-nproc'),
-         {'type': int, 'default': 1,
-          'help': 'Number of MPI processes to run tests on.'}),
-        (('--write-script', ),
-         {'type': str,
-          'help': 'Name of script that should be created to run tests.'}),
-        (('--separate-test', '--separate-tests'),
-         {'nargs': '+', 'action': 'extend', 'type': str,
-          'help': 'Flags defining tests that should be run separately.',
-          'dest': 'separate_tests'})]
-    allow_unknown = True
-
-    @classmethod
-    def add_arguments(cls, parser, **kwargs):
-        from yggdrasil import config
-        super(run_tsts, cls).add_arguments(parser, **kwargs)
-        parser = config.get_config_parser(parser)
-
-    @classmethod
-    def parse_args(cls, *args, **kwargs):
-        from yggdrasil import config, platform
-        args = super(run_tsts, cls).parse_args(*args, **kwargs)
-        extra = args._extra_commands
-        if args.ci:
-            requires_mpi = (
-                (args.test_suites and ('mpi' in args.test_suites))
-                or (args.with_mpi > 1))
-            args.verbose = True
-            args.withcoverage = True
-            args.setup_cfg = 'setup.cfg'
-            args.pytest_config = args.setup_cfg
-            args.cov_config = '.coveragerc'
-            if not args.ignore:
-                args.ignore = []
-            args.ignore.append('yggdrasil/rapidjson/')
-            args.rootdir = package_dir
-            if not requires_mpi:
-                extra += ['--reruns=2', '--reruns-delay=1', '--timeout=900']
-        if args.write_script:
-            if not os.path.isabs(args.write_script):
-                args.write_script = os.path.abspath(args.write_script)
-        # Separate out paths from options
-        test_paths = []
-        if args.test_suites:
-            if 'all' in args.test_suites:
-                args.test_suites.remove('all')
-                for x in ['top', 'examples', 'demos', 'types', 'timing',
-                          'connections', 'models', 'mpi']:
-                    if x not in args.test_suites:
-                        args.test_suites.append(x)
-            for x in args.test_suites:
-                if x == 'top':
-                    test_paths.append(package_dir)
-                elif x == 'examples':
-                    args.enable_examples = True
-                    test_paths.append('examples')
-                elif x == 'examples_part1':
-                    args.enable_examples = True
-                    if platform._is_win:  # pragma: windows
-                        pattern = 'test_[a-g]*.py'
-                    else:
-                        pattern = 'test_[A-Za-g]*.py'
-                    test_paths.append(os.path.join(
-                        'examples', 'tests', pattern))
-                elif x == 'examples_part2':
-                    args.enable_examples = True
-                    pattern = 'test_[h-z]*.py'
-                    test_paths.append(os.path.join(
-                        'examples', 'tests', pattern))
-                elif x == 'demos':
-                    args.enable_demos = True
-                    test_paths.append('demos')
-                elif x == 'types':
-                    args.enable_examples = True
-                    args.long_running = True
-                    test_paths.append(os.path.join('examples', 'tests',
-                                                   'test_types.py'))
-                elif x == 'timing':
-                    args.long_running = True
-                    args.enable_production_runs = True
-                    test_paths.append(os.path.join('tests', 'test_timing.py'))
-                elif x == 'connections':
-                    for f in ['test_ConnectionDriver.py',
-                              'test_FileInputDriver.py',
-                              'test_FileOutputDriver.py',
-                              'test_RPCRequestDriver.py']:
-                        test_paths.append(
-                            os.path.join('drivers', 'tests', f))
-                elif x == 'models':
-                    test_paths.append(
-                        os.path.join('drivers', 'tests',
-                                     'test_*ModelDriver.py'))
-                elif x == 'mpi':
-                    args.enable_examples = True
-                    if args.with_mpi == 1:
-                        args.with_mpi = 2
-                    test_paths += [
-                        os.path.join('communication', 'tests',
-                                     'test_MPIComm.py'),
-                        os.path.join('examples', 'tests',
-                                     'test_gs_lesson4.py'),
-                        os.path.join('examples', 'tests',
-                                     'test_rpc_lesson3b.py')]
-                    if not platform._is_win:
-                        test_paths += [
-                            os.path.join('examples', 'tests',
-                                         'test_model_error_with_io.py')]
-                    extra += ['-p', 'no:flaky']
-        if (not test_paths) and all(x.startswith('-') for x in extra):
-            test_paths.append(package_dir)
-        # Get expanded tests to allow for paths that are relative to
-        # either the yggdrasil root directory or the current working
-        # directory
-        args = config.resolve_config_parser(args)
-        args.extra = []
-        args.added_paths = test_paths
-        cls.expand_and_add(extra + test_paths, args.extra,
-                           [package_dir, os.getcwd()],
-                           add_on_nomatch=True)
-        return args
-
-    @classmethod
-    def expand_and_add(cls, path, path_list, dir_list,
-                       add_on_nomatch=False):
-        r"""Expand the specified path and add it's expanded forms to
-        the provided list.
-
-        Args:
-            path (str): Absolute/relative path with or without regex
-                wildcard expressions to expand.
-            path_list (list): Existing list that expansions should be
-                added to.
-            dir_list (list): Directories that should be tried for
-                relative paths.
-            add_on_nomatch (bool, optional): If True, path will be added
-                to path_list even if there are not matches. Defaults to
-                False.
-
-        Returns:
-            int: The number of expansions added to path_list.
-
-        """
-        import glob
-        if isinstance(path, list):
-            nadded = 0
-            for x in path:
-                nadded += cls.expand_and_add(x, path_list, dir_list,
-                                             add_on_nomatch=add_on_nomatch)
-            return nadded
-        if path.startswith('-'):
-            if add_on_nomatch:
-                path_list.append(path)
-                return 1
-            return 0
-        elif path.endswith('yggtest'):
-            return 0
-        elif os.path.isabs(path):
-            matches = sorted(glob.glob(path))
-            path_list += matches
-            if (not matches) and add_on_nomatch:
-                path_list.append(path)
-                return 1
-            return len(matches)
-        # Try checking for function
-        for func_sep in ['::', ':']:
-            if (func_sep in path):
-                prepath, mod = path.rsplit(func_sep, 1)
-                nadded = cls.expand_and_add(prepath, path_list, dir_list)
-                if nadded:
-                    for i in range(-nadded, 0):
-                        path_list[i] += '%s%s' % (func_sep, mod)
-                    return nadded
-        # Try directory prefixes
-        for path_prefix in dir_list:
-            nadded = cls.expand_and_add(os.path.join(path_prefix, path),
-                                        path_list, dir_list)
-            if nadded:
-                return nadded
-        if add_on_nomatch:
-            path_list.append(path)
-            return 1
-        return 0
-
-    @classmethod
-    def write_script(cls, args, argv, cfg_env):
-        r"""Write a script to run the pytest command.
-
-        """
-        import stat
-        from yggdrasil import platform
-        assert(not platform._is_win)
-        lines = ['#!/bin/bash']
-        for k, v in cfg_env.new_env.items():
-            if '"' in v:
-                lines.append('export %s=\'%s\'' % (k, v))
-            else:
-                lines.append('export %s=%s' % (k, v))
-        lines.append(' '.join(argv))
-        for k, v in cfg_env.old_env.items():
-            if v is None:
-                lines.append('unset %s' % k)
-            elif '"' in v:
-                lines.append('export %s=\'%s\'' % (k, v))
-            else:
-                lines.append('export %s=%s' % (k, v))
-        with open(args.write_script, 'w') as fd:
-            fd.write('\n'.join(lines))
-        os.chmod(args.write_script, (stat.S_IRWXU
-                                     | stat.S_IRGRP | stat.S_IXGRP
-                                     | stat.S_IROTH | stat.S_IXOTH))
-        print("Wrote test script to '%s':\n\t%s"
-              % (args.write_script, '\n\t'.join(lines)))
-                                     
-    @classmethod
-    def func(cls, args):
-        from yggdrasil import config, platform
-        argv = [sys.executable, '-m', 'pytest']
-        # test_paths = args.test_paths
-        if args.with_mpi > 1:
-            argv = ['mpiexec', '-n', str(args.with_mpi)] + argv + ['--with-mpi']
-        if args.verbose:
-            argv.append('-v')
-        if args.nocapture:
-            argv.append('-s')
-            argv += ['-o', 'log_cli=true']
-        if args.nologcapture:
-            argv += ['-o', 'log_cli=true']
-        if args.stop:
-            argv.append('-x')
-        if args.withcoverage:
-            # See information about getting coverage of test fixtures
-            # https://pytest-cov.readthedocs.io/en/stable/plugins.html
-            argv.append('--cov=%s' % package_dir)
-            # argv.append('--cov-append')
-        if args.noflaky:
-            argv += ['-p', 'no:flaky']
-        if args.pytest_config:
-            argv += ['-c', args.pytest_config]
-        if args.cov_config:
-            argv += ['--cov-config=%s' % args.cov_config]
-        if args.ignore:
-            argv += ['--ignore=%s' % x for x in args.ignore]
-        if args.rootdir:
-            argv += ['--rootdir=%s' % args.rootdir]
-        if args.additional_info:
-            argv += ['-r', args.additional_info]
-        argv += args.extra
-        # Run test command and perform cleanup before logging any errors
-        logger.info("Running \'%s\' from %s", ' '.join(argv), os.getcwd())
-        new_config = {}
-        # pth_file = 'ygg_coverage.pth'
-        # assert(not os.path.isfile(pth_file))
-        # # Get arguments for temporary test environment
-        # if args.withcoverage:
-        #     new_config['COVERAGE_PROCESS_START'] = 'True'
-        #     with open(pth_file, 'w') as fd:
-        #         fd.write("import coverage; coverage.process_startup()")
-        initial_dir = os.getcwd()
-        error_code = 0
-        with config.parser_config(args, **new_config) as cfg_env:
-            try:
-                # Perform CI specific pretest operations
-                if args.ci:
-                    if not os.path.isfile(args.setup_cfg):
-                        raise RuntimeError("The CI tests must be run "
-                                           "from the root directory "
-                                           "of the yggdrasil git "
-                                           "repository.")
-                    top_dir = os.path.dirname(os.getcwd())
-                    src_cmd = ('python -c \"import versioneer; '
-                               'print(versioneer.get_version())\"')
-                    dst_cmd = ('python -c \"import yggdrasil; '
-                               'print(yggdrasil.__version__)\"')
-                    src_ver = subprocess.check_output(src_cmd,
-                                                      shell=True)
-                    dst_ver = subprocess.check_output(dst_cmd,
-                                                      shell=True,
-                                                      cwd=top_dir)
-                    if src_ver != dst_ver:  # pragma: debug
-                        raise RuntimeError(("Versions do not match:\n"
-                                            "\tSource version: %s\n"
-                                            "\tBuild  version: %s\n")
-                                           % (src_ver, dst_ver))
-                    subprocess.check_call(
-                        ["flake8", "yggdrasil", "--append-config",
-                         args.setup_cfg])
-                    if os.environ.get("YGG_CONDA", None):
-                        subprocess.check_call(
-                            ["python", "create_coveragerc.py"])
-                    if not os.path.isfile(".coveragerc"):
-                        raise RuntimeError(".coveragerc file dosn't "
-                                           "exist.")
-                    with open(".coveragerc", "r") as fd:
-                        print(fd.read())
-                    subprocess.check_call(["yggdrasil", "info",
-                                           "--verbose"])
-                error_code = 0
-                if args.write_script and (not platform._is_win):
-                    cls.write_script(args, argv, cfg_env)
-                else:
-                    for x in range(args.count):
-                        x_error_code = subprocess.call(argv)
-                        if x_error_code != 0:
-                            error_code = x_error_code
-                            if args.stop:
-                                break
-            # except BaseException:
-            #     logger.exception('Error in running test.')
-            #     error_code = -1
-            finally:
-                os.chdir(initial_dir)
-                # if os.path.isfile(pth_file):
-                #     os.remove(pth_file)
-        if args.separate_tests and (error_code == 0):
-            import re
-            assert(not args.write_script)
-            new_args = args.separate_tests
-            args.test_suites = []
-            args.separate_tests = []
-            paths = []
-            cls.expand_and_add(args.added_paths, paths,
-                               [package_dir, os.getcwd()])
-            args.extra = [x for x in args.extra if
-                          ((x not in paths)
-                           and (not re.match(r".*test\_.*\.py.*", x)))]
-            for iargs in new_args:
-                if error_code:
-                    break
-                error_code = cls.call(args=(iargs.split() + args.extra),
-                                      namespace=copy.copy(args))
-        return error_code
-
-
 class timing_plots(SubCommand):
     r"""Create performance plots using timing results."""
 
@@ -1879,7 +1524,7 @@ class main(SubCommand):
                    yggcc, yggcompile, yggclean,
                    ygginstall, update_config,
                    regen_metaschema, regen_schema,
-                   yggmodelform, yggdevup, run_tsts,
+                   yggmodelform, yggdevup,
                    timing_plots, generate_gha_workflow,
                    integration_service_manager]
 
