@@ -100,16 +100,15 @@ class ForkComm(CommBase.CommBase):
         self.curr_comm_index = 0
         self.eof_recv = []
         self.eof_send = []
-        if pattern is None:
-            if kwargs.get('direction', 'send') == 'recv':
-                pattern = 'cycle'
-            else:
-                pattern = 'broadcast'
         self.pattern = pattern
         if kwargs.get('direction', 'send') == 'recv':
-            assert(self.pattern in ['cycle', 'gather'])
+            # if self.pattern is None:
+            #     self.pattern = 'cycle'
+            assert self.pattern in ['cycle', 'gather']
         else:
-            assert(self.pattern in ['cycle', 'scatter', 'broadcast'])
+            if self.pattern is None:
+                self.pattern = 'broadcast'
+            assert self.pattern in ['cycle', 'scatter', 'broadcast']
         address = kwargs.pop('address', None)
         if comm_list is None:
             if isinstance(address, list):
@@ -117,7 +116,7 @@ class ForkComm(CommBase.CommBase):
             else:
                 ncomm = 0
             comm_list = [None for i in range(ncomm)]
-        assert(isinstance(comm_list, list))
+        assert isinstance(comm_list, list)
         ncomm = len(comm_list)
         for i in range(ncomm):
             if comm_list[i] is None:
@@ -130,7 +129,7 @@ class ForkComm(CommBase.CommBase):
                                      "root ForkComm and a child comm, but can only "
                                      "be present for one." % k)
         if isinstance(address, list):
-            assert(len(address) == ncomm)
+            assert len(address) == ncomm
             for i in range(ncomm):
                 comm_list[i]['address'] = address[i]
         for i in range(ncomm):
@@ -147,9 +146,9 @@ class ForkComm(CommBase.CommBase):
             kwargs['address'] = [x.address for x in self.comm_list]
         kwargs.update(noprop_kwargs)
         super(ForkComm, self).__init__(name, is_async=is_async, **kwargs)
-        assert(not self.single_use)
-        assert(not self.is_server)
-        assert(not (self.is_client and (self.pattern != 'cycle')))
+        assert not self.single_use
+        assert not self.is_server
+        assert not (self.is_client and (self.pattern != 'cycle'))
 
     def disconnect(self):
         r"""Disconnect attributes that are aliases."""
@@ -212,7 +211,7 @@ class ForkComm(CommBase.CommBase):
             ncomm = kwargs.pop('ncomm', 0)
             if comm_list is None:
                 comm_list = [None for i in range(ncomm)]
-            assert(isinstance(comm_list, list))
+            assert isinstance(comm_list, list)
             ncomm = len(comm_list)
             for i in range(ncomm):
                 x = comm_list[i]
@@ -287,7 +286,7 @@ class ForkComm(CommBase.CommBase):
     @property
     def get_response_comm_kwargs(self):
         r"""dict: Keyword arguments to use for a response comm."""
-        assert(self.pattern == 'cycle')
+        assert self.pattern == 'cycle'
         return self.curr_comm.get_response_comm_kwargs
         
     def bind(self):
@@ -347,6 +346,28 @@ class ForkComm(CommBase.CommBase):
                 return False
         return True
 
+    @property
+    def n_msg_direct_recv(self):
+        r"""int: Number of messages currently being routed in recv."""
+        if self.pattern == 'gather':
+            return min([x.n_msg_direct_recv for x in self.comm_list])
+        return sum([x.n_msg_direct_recv for x in self.comm_list])
+        
+    @property
+    def n_msg_direct_send(self):
+        r"""int: Number of messages currently being routed in send."""
+        if self.pattern in ['broadcast', 'scatter']:
+            return max([x.n_msg_direct_send for x in self.comm_list])
+        return sum([x.n_msg_direct_send for x in self.comm_list])
+
+    @property
+    def n_msg_direct(self):
+        r"""int: Number of messages currently being routed."""
+        if self.direction == 'send':
+            return self.n_msg_direct_send
+        else:
+            return self.n_msg_direct_recv
+
     @property
     def n_msg_recv(self):
         r"""int: The number of incoming messages in the connection."""
@@ -387,6 +408,17 @@ class ForkComm(CommBase.CommBase):
         """
         if msg.stype is not None:
             msg.stype = self.apply_transform_to_type(msg.stype)
+            if (self.direction == 'send') and (self.pattern == 'scatter'):
+                if msg.stype['type'] != 'array':  # pragma: debug
+                    raise RuntimeError("Only 'array' type messages can be "
+                                       "scattered.")
+                for i, x in enumerate(self.comm_list):
+                    imsg = copy.deepcopy(msg)
+                    imsg.header = {}
+                    imsg.stype = msg.stype['items'][i]
+                    imsg.args = msg.args[i]
+                    x.update_serializer_from_message(imsg)
+                return
         for x in self.comm_list:
             x.update_serializer_from_message(msg)
         
@@ -423,7 +455,7 @@ class ForkComm(CommBase.CommBase):
             bool: Success or failure of send.
         
         """
-        assert(isinstance(msg.args, dict))
+        assert isinstance(msg.args, dict)
         for idx in range(len(self)):
             i = self.curr_comm_index % len(self)
             x = self.curr_comm
@@ -485,8 +517,8 @@ class ForkComm(CommBase.CommBase):
                         if msg.flag == CommBase.FLAG_EOF:
                             self.eof_recv[idx] = 1
                             if self.pattern == 'gather':
-                                assert(all((v.flag == CommBase.FLAG_EOF)
-                                           for v in out_gather.values()))
+                                assert all((v.flag == CommBase.FLAG_EOF)
+                                           for v in out_gather.values())
                                 out_gather[idx] = msg
                             elif sum(self.eof_recv) == len(self):
                                 out_gather[idx] = msg
@@ -540,7 +572,7 @@ class ForkComm(CommBase.CommBase):
                     v, skip_python2language=True)
                 for idx, v in msg.args.items()}
             if self.pattern == 'cycle':
-                assert(len(msg.args) == 1)
+                assert len(msg.args) == 1
                 msg = next(iter(msg.args.values()))
             elif msg.flag == CommBase.FLAG_EOF:
                 msg.args = msg.args[0].args
@@ -601,7 +633,7 @@ class ForkComm(CommBase.CommBase):
 
         """
         if self.pattern in ['scatter', 'gather']:
-            assert(isinstance(msg, (list, tuple)) and (len(msg) == len(self)))
+            assert isinstance(msg, (list, tuple)) and (len(msg) == len(self))
             out = [x.coerce_to_dict(msg[i], key_order, metadata)
                    for i, x in enumerate(self.comm_list)]
             return out
