@@ -52,6 +52,7 @@ class RemoteTaskLoop(multitasking.YggTaskLoop):
             task_context=connection.process_instance.context)
         super(RemoteTaskLoop, self).__init__(target=self.target, **kwargs)
         # Overwrite break flag with process safe Event
+        self.break_flag.disconnect()
         self.break_flag = multitasking.Event(
             task_method='process',
             task_context=connection.process_instance.context)
@@ -81,9 +82,9 @@ class RemoteTaskLoop(multitasking.YggTaskLoop):
 
     def run_task_remote(self, task, args, kwargs):
         r"""Run task on the connection loop process."""
-        assert(self.connection.as_process
-               and (not self.connection.in_process)
-               and self.connection.is_alive())
+        assert (self.connection.as_process
+                and (not self.connection.in_process)
+                and self.connection.is_alive())
         if self.break_flag.is_set():  # pragma: debug
             raise TaskThreadError("Task thread was stopped.")
         self.q_tasks.put_nowait((task, args, kwargs))
@@ -134,6 +135,22 @@ class ConnectionDriver(Driver):
         outputs (list, optional): One or more dictionaries containing keyword
             arguments for constructing output communicators. Defaults to an
             empty dictionary if not provided.
+        input_pattern (str, optional): The communication pattern that should
+            be used to handle incoming messages when there is more than one
+            input communicators present. Defaults to 'cycle'. Options
+            include:
+              'cycle': Receive from the next available input communicator.
+              'gather': Receive lists of messages with one element from each
+                  communicator where a message is only returned when there is
+                  a message from each.
+        output_pattern (str, optional): The communication pattern that should
+            be used to handling outgoing messages when there is more than one
+            output communicator present. Defaults to 'broadcast'. Options
+            include:
+              'cycle': Rotate through output comms, sending one message to
+                  each.
+              'broadcast': Send the same message to each comm.
+              'scatter': Send part of message (must be a list) to each comm.
         translator (str, func, optional): Function or string specifying function
             that should be used to translate messages from the input communicator
             before passing them to the output communicator. If a string, the
@@ -205,6 +222,12 @@ class ConnectionDriver(Driver):
                         'A full description of file entries and the '
                         'available options can be found :ref:`here<'
                         'yaml_file_options>`.')},
+        'input_pattern': {'type': 'string',
+                          'enum': ['cycle', 'gather'],
+                          'default': 'cycle'},
+        'output_pattern': {'type': 'string',
+                           'enum': ['cycle', 'broadcast', 'scatter'],
+                           'default': 'broadcast'},
         'translator': {'type': 'array',
                        'items': {'oneOf': [
                            {'type': 'function'},
@@ -212,7 +235,8 @@ class ConnectionDriver(Driver):
         'onexit': {'type': 'string'}}
     _schema_excluded_from_class_validation = ['inputs', 'outputs']
     _disconnect_attr = Driver._disconnect_attr + [
-        '_comm_closed', '_skip_after_loop', 'shared', 'task_thread']
+        '_comm_closed', '_skip_after_loop', 'shared', 'task_thread',
+        'icomm', 'ocomm']
 
     def __init__(self, name, translator=None, single_use=False, onexit=None,
                  models=None, **kwargs):
@@ -269,8 +293,8 @@ class ConnectionDriver(Driver):
         r"""Parse keyword arguments for input/output comm."""
         self.debug("Creating %s comm", io)
         comm_kws = dict()
-        assert(isinstance(comm_list, list))
-        assert(comm_list)
+        assert isinstance(comm_list, list)
+        assert comm_list
         if io == 'input':
             direction = 'recv'
             attr_comm = 'icomm'
@@ -285,11 +309,13 @@ class ConnectionDriver(Driver):
         comm_kws['reverse_names'] = True
         comm_kws['use_async'] = True
         comm_kws['name'] = self.name
+        if len(comm_list) > 0:
+            comm_kws['pattern'] = getattr(self, f'{io}_pattern')
         for i, x in enumerate(comm_list):
             if x is None:
                 comm_list[i] = dict()
             else:
-                assert(isinstance(x, dict))
+                assert isinstance(x, dict)
             if 'filetype' not in comm_list[i]:
                 comm_list[i].setdefault('commtype', comm_type)
             if self.as_process:
@@ -326,6 +352,7 @@ class ConnectionDriver(Driver):
             self._init_single_comm('output', self.outputs)
         except BaseException:
             self.icomm.close()
+            self.icomm.disconnect()
             raise
         # Apply keywords dependent on comms
         if self.icomm.any_files:
@@ -496,11 +523,13 @@ class ConnectionDriver(Driver):
             try:
                 if getattr(self, 'icomm', None) is not None:
                     self.icomm.close()
+                    self.icomm.disconnect()
             except BaseException as e:
                 ie = e
             try:
                 if getattr(self, 'ocomm', None) is not None:
                     self.ocomm.close()
+                    self.ocomm.disconnect()
             except BaseException as e:
                 oe = e
             if ie:
@@ -752,7 +781,7 @@ class ConnectionDriver(Driver):
             self.open_comm()
             self.sleep()  # Help ensure senders/receivers connected before messages
             self.debug('Running in %s, is_valid = %s', os.getcwd(), str(self.is_valid))
-            assert(self.is_valid)
+            assert self.is_valid
         except BaseException:  # pragma: debug
             self.printStatus()
             self.exception('Could not prep for loop (is_open = (%s, %s)).' % (
@@ -804,7 +833,7 @@ class ConnectionDriver(Driver):
             CommMessage, bool: False if no more messages, message otherwise.
 
         """
-        assert(self.in_process)
+        assert self.in_process
         kwargs.setdefault('timeout', 0)
         with self.lock:
             if self.icomm.is_closed:
@@ -859,13 +888,9 @@ class ConnectionDriver(Driver):
 
     def update_serializer(self, msg):
         r"""Update the serializer for the output comm based on input."""
-        self.debug('Before update:\n'
-                   + '  icomm:\n    sinfo:\n%s\n    typedef:\n%s\n'
-                   + '  ocomm:\n    sinfo:\n%s\n    typedef:\n%s',
-                   self.pprint(self.icomm.serializer.serializer_info, 2),
-                   self.pprint(self.icomm.serializer.typedef, 2),
-                   self.pprint(self.ocomm.serializer.serializer_info, 2),
-                   self.pprint(self.ocomm.serializer.typedef, 2))
+        self.debug('Before update:\n  icomm:%s\n  ocomm:%s\n'
+                   % ("\n".join(self.icomm.get_status_message(nindent=1)[0][1:]),
+                      "\n".join(self.ocomm.get_status_message(nindent=1)[0][1:])))
         for t in self.translator:
             if isinstance_component(t, 'transform'):
                 t.set_original_datatype(msg.stype)
@@ -880,13 +905,9 @@ class ConnectionDriver(Driver):
             #      and (self.ocomm.serializer.typedef['type'] != 'array')
             #      and (len(self.icomm.serializer.typedef['items']) == 1))):
             self.translator.insert(0, _translate_list2element)
-        self.debug('After update:\n'
-                   + '  icomm:\n    sinfo:\n%s\n    typedef:\n%s\n'
-                   + '  ocomm:\n    sinfo:\n%s\n    typedef:\n%s',
-                   self.pprint(self.icomm.serializer.serializer_info, 2),
-                   self.pprint(self.icomm.serializer.typedef, 2),
-                   self.pprint(self.ocomm.serializer.serializer_info, 2),
-                   self.pprint(self.ocomm.serializer.typedef, 2))
+        self.debug('After update:\n  icomm:\n%s\n  ocomm:\n%s\n'
+                   % ("\n".join(self.icomm.get_status_message(nindent=1)[0][1:]),
+                      "\n".join(self.ocomm.get_status_message(nindent=1)[0][1:])))
 
     def _send_message(self, *args, **kwargs):
         r"""Send a single message.
@@ -965,7 +986,7 @@ class ConnectionDriver(Driver):
             bool: Success or failure of send.
 
         """
-        assert(self.in_process)
+        assert self.in_process
         self.debug('')
         with self.lock:
             self._used = True
