@@ -125,7 +125,7 @@ class MakeCompiler(BuildToolBase):
 
         """
         if not kwargs.get('skip_flags', False):
-            assert(len(args) <= 1)
+            assert len(args) <= 1
             if len(args) == 1:
                 if target is None:
                     target = cls.file2base(args[0])
@@ -200,10 +200,11 @@ class MakeModelDriver(BuildModelDriver):
             cls.default_compiler = 'nmake'
         
     @classmethod
-    def mpi_partner_cleanup(cls, self):
-        r"""Actions cleaning up an MPIPartnerModel."""
-        super(MakeModelDriver, cls).mpi_partner_cleanup(self)
-        cls.partner_buildfile_lock(self)
+    def get_buildfile_lock(cls, **kwargs):
+        r"""Get a lock for a buildfile to prevent simultaneous access,
+        creating one as necessary."""
+        kwargs.setdefault('when_to_lock', 'cleanup')
+        return super(MakeModelDriver, cls).get_buildfile_lock(**kwargs)
         
     def parse_arguments(self, args, **kwargs):
         r"""Sort arguments based on their syntax to determine if an argument
@@ -270,7 +271,8 @@ class MakeModelDriver(BuildModelDriver):
                                   # source_files=[],  # Unknown source files, use target
                                   for_model=False,  # flags are in environment
                                   working_dir=self.makedir,
-                                  makefile=self.buildfile)
+                                  makefile=self.buildfile,
+                                  dont_lock_buildfile=True)
             if target is not None:
                 default_kwargs['target'] = target
             for k, v in default_kwargs.items():
