@@ -302,7 +302,7 @@ class RModelDriver(InterpretedModelDriver):  # pragma: R
                 for m in re.finditer(cls.function_param['interface_regex'],
                                      contents):
                     mdict = m.groupdict()
-                    assert('global_scope' in mdict['args'])
+                    assert 'global_scope' in mdict['args']
                     # if 'global_scope' not in mdict['args']:
                     #     mdict['args'] += ', global_scope=TRUE'
                     new_channel = (
@@ -347,7 +347,7 @@ class RModelDriver(InterpretedModelDriver):  # pragma: R
         if flags is None:
             flags = []
         if isinstance(package_dir, list):
-            assert(len(package_dir) == 1)
+            assert len(package_dir) == 1
             package_dir = package_dir[0]
         cexec_vars = {'c': ['CC', 'CC_FOR_BUILD'],
                       'c++': ['CXX', 'CPP', 'CXX98', 'CXX11', 'CXX14',
@@ -479,6 +479,30 @@ class RModelDriver(InterpretedModelDriver):  # pragma: R
         ]
         return out
 
+    @classmethod
+    def write_expand_single_element(cls, output_var, add_cond=False):
+        r"""Write lines allowing extraction of the only element from a single
+        element array as a stand-alone variable if the variable is an array
+        and only has one element.
+
+        Args:
+            output_var (str): Name of the variable that should be conditionally
+                expanded.
+            add_cond (str, optional): Additional condition that must be
+                satisfied for the array element to be extracted. Defaults to
+                False and is ignored.
+
+        Returns:
+            list: Lines added the conditional expansion of single element
+                arrays.
+
+        """
+        if not add_cond:
+            add_cond = []
+        add_cond.append(f"is.null(names({output_var}))")
+        return super(RModelDriver, cls).write_expand_single_element(
+            output_var, add_cond)
+        
     @classmethod
     def install_dependency(cls, package, package_manager=None, **kwargs):
         r"""Install a dependency.
@@ -506,3 +530,35 @@ class RModelDriver(InterpretedModelDriver):  # pragma: R
                   f'repos=\"http://cloud.r-project.org\")\'')])
         return super(RModelDriver, cls).install_dependency(
             package, package_manager=package_manager, **kwargs)
+
+    @classmethod
+    def get_testing_options(cls, **kwargs):
+        r"""Method to return a dictionary of testing options for this class.
+
+        Args:
+            **kwargs: Additional keyword arguments are passed to the parent
+                class.
+
+        Returns:
+            dict: Dictionary of variables to use for testing. Key/value pairs:
+                kwargs (dict): Keyword arguments for driver instance.
+                deps (list): Dependencies to install.
+
+        """
+        out = super(RModelDriver, cls).get_testing_options(**kwargs)
+        out['kwargs']['interpreter_flags'] = ['--vanilla']
+        out.update(
+            deps=['units', 'zeallot',
+                  {'package': 'units', 'arguments': '-v'}],
+            python2language=[
+                (np.string_('hello'), 'hello'),
+                ((np.string_('hello'), ), ('hello', )),
+                ([np.string_('hello')], ['hello']),
+                ({np.string_('hello'): np.string_('hello')},
+                 {'hello': 'hello'}),
+                (OrderedDict([(np.string_('hello'), np.string_('hello'))]),
+                 OrderedDict([('hello', 'hello')])),
+                (pd.DataFrame.from_dict({'a': np.zeros(5, dtype='int64')}),
+                 pd.DataFrame.from_dict({'a': np.zeros(5, dtype='int32')}))],
+            invalid_libraries=['invalid_unicorn'])
+        return out
